Author: dmeyer
Date: Thu Apr 13 17:02:01 2006
New Revision: 8151

Modified:
   trunk/ui/src/input/plugins/x11.py

Log:
update doc

Modified: trunk/ui/src/input/plugins/x11.py
==============================================================================
--- trunk/ui/src/input/plugins/x11.py   (original)
+++ trunk/ui/src/input/plugins/x11.py   Thu Apr 13 17:02:01 2006
@@ -1,44 +1,54 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-#
-# x11.py
-# 
-# Author:   <[EMAIL PROTECTED]>
-# 
-# x11
-# 
+# -*- coding: iso-8859-1 -*-
+# -----------------------------------------------------------------------------
+# x11.py - X11 window key input plugin
+# -----------------------------------------------------------------------------
 # $Id$
-# 
-# Copyright (C) 2004 Andreas B�sching <[EMAIL PROTECTED]>
-# 
+#
+# -----------------------------------------------------------------------------
+# Freevo - A Home Theater PC framework
+# Copyright (C) 2002-2005 Krister Lagerstrom, Dirk Meyer, et al.
+#
+# First Edition: Andreas B�sching <[EMAIL PROTECTED]>
+# Maintainer:    Dirk Meyer <[EMAIL PROTECTED]>
+#
+# Please see the file AUTHORS for a complete list of authors.
+# Some of the work from Andreas B�sching is moved into kaa.display
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2, or (at your option)
-# any later version.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of MER-
+# CHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
+# Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+#
+# -----------------------------------------------------------------------------
+
+# python imports
+import logging
 
+# freevo imports
 import gui
 import config
 
+# input imports
 from input import linux_input
 from input.interface import InputPlugin
 
-import logging
+# get logging object
 log = logging.getLogger('input')
 
 SCREENSHOT = 0
 
 class PluginInterface(InputPlugin):
     """
-    Plugin for pygame input events
+    Plugin for x11 keys.
     """
     def __init__(self):
         InputPlugin.__init__(self)
@@ -47,7 +57,7 @@
 
     def handle( self, keycode ):
         """
         Callback to handle the pygame events.
         """
         if keycode == 353:
             global SCREENSHOT
@@ -56,7 +66,7 @@
             gui.display._backing_store._image.save(filename)
             SCREENSHOT += 1
             return True
-        
+
         if isinstance(keycode, int):
             log.debug('Bad keycode %s' % keycode)
             return True


-------------------------------------------------------
@@ -47,7 +57,7 @@
     def handle( self, keycode ):
         """
-        Callback to handle the pygame events.
+        Callback to handle the x11 keys.
         """
         if keycode == 353:
This SF.Net email is sponsored by xPML, a groundbreaking scripting language
that extends applications into web and mobile media. Attend the live webcast
and join the prime developer group breaking into this new coding territory!
http://sel.as-us.falkag.net/sel?cmd=lnk&kid=110944&bid=241720&dat=121642
_______________________________________________
Freevo-cvslog mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/freevo-cvslog

Reply via email to